function [ret,x0,str,ts,xts]=prec_sim(t,x,u,flag);
%PREC_SIM	is the M-file description of the SIMULINK system named PREC_SIM.
%	The block-diagram can be displayed by typing: PREC_SIM.
%
%	SYS=PREC_SIM(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes PREC_SIM to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling PREC_SIM with a FLAG of zero:
%	[SIZES]=PREC_SIM([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[-32000,-32000,-31840,-31975])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '20000')
set_param(sys,'Min step size', '0.5')
set_param(sys,'Max step size', '1')
set_param(sys,'Relative error','1e-5')
set_param(sys,'Return vars',   '')

add_block('built-in/Note',[sys,'/',['Rduction du tumbling - mise en spin - mode survie altern',13,' d''un nanosatellite ( technique de Steyn )']])
set_param([sys,'/',['Rduction du tumbling - mise en spin - mode survie altern',13,' d''un nanosatellite ( technique de Steyn )']],...
		'ForeGround',5,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',26)
set_param([sys,'/',['Rduction du tumbling - mise en spin - mode survie altern',13,' d''un nanosatellite ( technique de Steyn )']],...
		'position',[663,0,668,5])


%     Subsystem  'Extras8'.

new_system([sys,'/','Extras8'])
set_param([sys,'/','Extras8'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras8'],...
		'Mask Display','Voir courbe\ncouple de\ncommande (Nm)',...
		'Mask Dialogue','eval(''plot(temps,cpl_steyn);grid;figure(gcf)'')')


%     Finished composite block 'Extras8'.

set_param([sys,'/','Extras8'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[640,780,815,846])


%     Subsystem  'Extras11'.

new_system([sys,'/','Extras11'])
set_param([sys,'/','Extras11'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras11'],...
		'Mask Display','Voir les courbes\nvitesses angulaires\nsatellite/XYZ (/s)',...
		'Mask Dialogue','eval(''plot(temps,omega_quat);grid;figure(gcf)'')')


%     Finished composite block 'Extras11'.

set_param([sys,'/','Extras11'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[640,705,810,766])


%     Subsystem  'Extras5'.

new_system([sys,'/','Extras5'])
set_param([sys,'/','Extras5'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras5'],...
		'Mask Display','Voir les courbes\ndes angles (en degrs)',...
		'Mask Dialogue','eval(''plot(temps,roulis,temps,tangage,temps,lacet);grid;figure(gcf)'')')


%     Finished composite block 'Extras5'.

set_param([sys,'/','Extras5'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[125,625,325,691])

add_block('built-in/Note',[sys,'/',['4  7 = quaternion d''attitude dans le repre orbital']])
set_param([sys,'/',['4  7 = quaternion d''attitude dans le repre orbital']],...
		'position',[650,505,655,510])

add_block('built-in/Note',[sys,'/','1  3 = rotation inertielle'])
set_param([sys,'/','1  3 = rotation inertielle'],...
		'position',[240,510,245,515])

add_block('built-in/Note',[sys,'/',['Vecteur d''tat de 7 composantes']])
set_param([sys,'/',['Vecteur d''tat de 7 composantes']],...
		'position',[425,485,430,490])

add_block('built-in/Note',[sys,'/',['Entres',13,'drive rotation (3)']])
set_param([sys,'/',['Entres',13,'drive rotation (3)']],...
		'position',[480,240,485,245])


%     Subsystem  'F(X,t) pour la rotation'.

new_system([sys,'/','F(X,t) pour la rotation'])
set_param([sys,'/','F(X,t) pour la rotation'],'Location',[-32000,-32000,-31840,-31975])

add_block('built-in/State-Space',[sys,'/',['F(X,t) pour la rotation/Inverse matrice',13,'satellite1']])
set_param([sys,'/',['F(X,t) pour la rotation/Inverse matrice',13,'satellite1']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','inv(Asat)',...
		'Mask Display','Inv(Asat)',...
		'Mask Type','Matrix Gain')
set_param([sys,'/',['F(X,t) pour la rotation/Inverse matrice',13,'satellite1']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'position',[440,347,540,393])


%     Subsystem  ['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1'].

new_system([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],'Location',[4,50,1271,885])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/B']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/B']],...
		'position',[510,425,515,430])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Vecteur d''tat',13,'7 composantes',13,'p q r Q']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Vecteur d''tat',13,'7 composantes',13,'p q r Q']],...
		'position',[140,515,145,520])

add_block('built-in/Gain',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Gain3']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Gain3']],...
		'hide name',0,...
		'Gain','-1',...
		'position',[800,382,835,408])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Couple magntique rsiduel']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Couple magntique rsiduel']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[880,399,885,404])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Couple arodynamique']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Couple arodynamique']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[690,277,695,282])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Produit',13,'vectoriel1']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Produit',13,'vectoriel1']],...
		'MATLAB Fcn','norm(u,2)',...
		'Output Width','1',...
		'position',[770,438,830,472])

add_block('built-in/Gain',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Gain']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Gain']],...
		'Gain','mom_magn_res',...
		'position',[375,315,490,365])

add_block('built-in/To Workspace',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/To Workspace']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/To Workspace']],...
		'hide name',0,...
		'mat-name','moment_residuel',...
		'buffer','5000',...
		'position',[895,440,1015,470])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Moment magntique rsiduel']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Moment magntique rsiduel']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[245,246,250,251])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Produit',13,'vectoriel']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Produit',13,'vectoriel']],...
		'MATLAB Fcn','prodvect(u)',...
		'Output Width','3',...
		'position',[640,378,700,412])

add_block('built-in/Mux',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Mux5']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Mux5']],...
		'inputs','[3 3]',...
		'position',[540,286,585,504])

add_block('built-in/Mux',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Mux3']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Mux3']],...
		'ForeGround',1,...
		'BackGround',0,...
		'inputs','3',...
		'position',[320,288,350,392])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant12']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant12']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','alpha',...
		'position',[130,293,275,317])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant11']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant11']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','beta',...
		'position',[130,328,275,352])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant10']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant10']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','gamma',...
		'position',[130,363,275,387])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/M']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/M']],...
		'position',[525,315,530,320])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant6']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant6']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','cpl_aero3',...
		'position',[785,318,930,342])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant5']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant5']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','cpl_aero2',...
		'position',[785,283,930,307])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant4']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant4']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','cpl_aero1',...
		'position',[785,248,930,272])

add_block('built-in/Mux',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Mux1']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Mux1']],...
		'ForeGround',1,...
		'BackGround',0,...
		'inputs','3',...
		'position',[975,243,1005,347])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Termes rsidus de gradient',13,'et forces inertie']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Termes rsidus de gradient',13,'et forces inertie']],...
		'ForeGround',4,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[895,195,900,200])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant3']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant3']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Value','Irt*vitesse_rotation^2',...
		'position',[795,158,940,182])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant2']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant2']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Value','3*Irl*vitesse_rotation^2',...
		'position',[795,123,940,147])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant1']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant1']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Value','-4*Itl*vitesse_rotation^2',...
		'position',[795,88,940,112])

add_block('built-in/Mux',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Mux']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Mux']],...
		'ForeGround',7,...
		'BackGround',0,...
		'inputs','3',...
		'position',[985,83,1015,187])


%     Subsystem  ['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite'].

new_system([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],'Location',[195,288,1041,757])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn3']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn3']],...
		'hide name',0,...
		'MATLAB Fcn','champmgn(u)',...
		'Output Width','3')
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn3']],...
		'Mask Display','CHAMP MAGNETIQUE\nREPERE ORBITAL',...
		'position',[250,95,425,145])

add_block('built-in/Clock',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Clock']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Clock']],...
		'position',[180,104,215,136])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/BX BY BZ']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/BX BY BZ']],...
		'position',[340,70,345,75])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Vecteur d''tat ',13,'( 7 composantes)']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Vecteur d''tat ',13,'( 7 composantes)']],...
		'position',[70,235,75,240])

add_block('built-in/Inport',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/in_1']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/in_1']],...
		'position',[50,190,70,210])

add_block('built-in/Outport',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/out_1']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/out_1']],...
		'position',[705,150,725,170])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Sortie Bx By Bz']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Sortie Bx By Bz']],...
		'position',[725,200,730,205])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Equateur au temps 0 s']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Equateur au temps 0 s']],...
		'position',[150,75,155,80])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn1']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn1']],...
		'MATLAB Fcn','champsat(u)',...
		'Output Width','3',...
		'position',[560,143,620,177])

add_block('built-in/Mux',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Mux1']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Mux1']],...
		'inputs','[3 7]',...
		'position',[485,80,530,240])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[220,120;245,120])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[430,120;480,120])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[625,160;700,160])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[75,200;480,200])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[535,160;555,160])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],...
		'Mask Display','CHAMP MAGNETIQUE EN\nAXES SATELLITE\nEntre=vecteur d''tat\nSortie Bx By Bz')


%     Finished composite block ['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite'].

set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],...
		'position',[240,458,440,532])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']],...
		'Font Name','Arial')
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']],...
		'Font Size',16)
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']],...
		'position',[385,95,390,100])

add_block('built-in/Inport',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Inport']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Inport']],...
		'position',[20,485,40,505])

add_block('built-in/Sum',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Sum']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Sum']],...
		'inputs','++++',...
		'position',[1090,254,1125,361])

add_block('built-in/Outport',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Outport']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Outport']],...
		'position',[1200,300,1220,320])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']],...
		'ForeGround',2,...
		'Font Name','Arial',...
		'Font Size',14)
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']],...
		'position',[665,505,670,510])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Partie principale du gradient de gravit']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Partie principale du gradient de gravit']],...
		'position',[945,540,950,545])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/MATLAB Fcn']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/MATLAB Fcn']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'MATLAB Fcn','gradgrav(u)',...
		'Output Width','3')
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/MATLAB Fcn']],...
		'Mask Display','GRADIENT PRINCIPAL\n\nDE GRAVITE',...
		'position',[630,554,805,606])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[45,495;235,495])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[840,395;1055,395;1055,320;1085,320])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[705,395;735,395;735,455;765,455])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[735,395;795,395])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[835,455;890,455])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[590,395;635,395])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[445,495;470,495;470,450;535,450])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[495,340;535,340])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[355,340;370,340])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[280,305;315,305])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[280,340;315,340])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[280,375;315,375])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[945,100;980,100])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[945,135;980,135])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[945,170;980,170])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[935,260;970,260])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[935,295;970,295])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[1010,295;1085,295])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[935,330;970,330])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[1020,135;1075,135;1085,270])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[75,495;75,580;625,580])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[1130,310;1195,310])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[810,580;1070,580;1070,345;1085,345])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],...
		'Mask Display','Couples\nperturbateurs Mp')


%     Finished composite block ['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1'].

set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],...
		'ForeGround',2,...
		'hide name',0,...
		'position',[260,342,390,398])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/pqr'])
set_param([sys,'/','F(X,t) pour la rotation/pqr'],...
		'position',[310,430,315,435])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/Q'])
set_param([sys,'/','F(X,t) pour la rotation/Q'],...
		'position',[305,525,310,530])

add_block('built-in/Demux',[sys,'/','F(X,t) pour la rotation/Demux'])
set_param([sys,'/','F(X,t) pour la rotation/Demux'],...
		'outputs','[3 4]',...
		'position',[235,435,285,555])

add_block('built-in/MATLAB Fcn',[sys,'/','F(X,t) pour la rotation/magneto.m1'])
set_param([sys,'/','F(X,t) pour la rotation/magneto.m1'],...
		'MATLAB Fcn','derivrot(u)',...
		'Output Width','3',...
		'Mask Display','DERIVROT(u)',...
		'position',[355,439,480,491])

add_block('built-in/Gain',[sys,'/','F(X,t) pour la rotation/Gain'])
set_param([sys,'/','F(X,t) pour la rotation/Gain'],...
		'Gain','K_perturbation',...
		'position',[725,357,750,383])

add_block('built-in/State-Space',[sys,'/',['F(X,t) pour la rotation/Inverse matrice',13,'satellite']])
set_param([sys,'/',['F(X,t) pour la rotation/Inverse matrice',13,'satellite']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','inv(Asat)',...
		'Mask Display','Inv(Asat)',...
		'Mask Type','Matrix Gain')
set_param([sys,'/',['F(X,t) pour la rotation/Inverse matrice',13,'satellite']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'position',[680,252,780,298])

add_block('built-in/Sum',[sys,'/','F(X,t) pour la rotation/Sum1'])
set_param([sys,'/','F(X,t) pour la rotation/Sum1'],...
		'inputs','+++',...
		'position',[800,229,840,511])

add_block('built-in/Gain',[sys,'/','F(X,t) pour la rotation/Gain1'])
set_param([sys,'/','F(X,t) pour la rotation/Gain1'],...
		'position',[875,357,900,383])

add_block('built-in/Outport',[sys,'/','F(X,t) pour la rotation/out_1'])
set_param([sys,'/','F(X,t) pour la rotation/out_1'],...
		'position',[945,360,965,380])

add_block('built-in/Gain',[sys,'/','F(X,t) pour la rotation/Gain2'])
set_param([sys,'/','F(X,t) pour la rotation/Gain2'],...
		'Gain','K_commande',...
		'position',[620,263,660,287])

add_block('built-in/Inport',[sys,'/','F(X,t) pour la rotation/Inport'])
set_param([sys,'/','F(X,t) pour la rotation/Inport'],...
		'position',[50,360,70,380])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Vecteur d''tat ',13,'7 composantes',13,'p q r Q']])
set_param([sys,'/',['F(X,t) pour la rotation/Vecteur d''tat ',13,'7 composantes',13,'p q r Q']],...
		'position',[60,395,65,400])


%     Subsystem  'F(X,t) pour la rotation/Prcession vers soleil '.

new_system([sys,'/','F(X,t) pour la rotation/Prcession vers soleil '])
set_param([sys,'/','F(X,t) pour la rotation/Prcession vers soleil '],'Location',[-32000,-32000,-31840,-31975])

add_block('built-in/Clock',[sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Clock'])
set_param([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Clock'],...
		'position',[215,467,250,503])


%     Subsystem  ['F(X,t) pour la rotation/Prcession vers soleil /Champ magntique',13,'en axes satellite_'].

new_system([sys,'/',['F(X,t) pour la rotation/Prcession vers soleil /Champ magntique',13,'en axes satellite_']])
set_param([sys,'/',['F(X,t) pour la rotation/Prcession vers soleil /Champ magntique',13,'en axes satellite_']],'Location',[59,535,1014,1004])

add_block('built-in/Mux',[sys,'/',['F(X,t) pour la rotation/Prcession vers soleil /Champ magntique',13,'en axes satellite_/Mux1']])
set_param([sys,'/',['F(X,t) pour la rotation/Prcession vers soleil /Champ magntique',13,'en axes satellite_/Mux1']],...
		'inputs','[3 7]',...
		'position',[485,80,530,240])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Prcession vers soleil /Champ magntique',13,'en axes satellite_/MATLAB Fcn1']])
set_param([sys,'/',['F(X,t) pour la rotation/Prcession vers soleil /Champ magntique',13,'en axes satellite_/MATLAB Fcn1']],...
		'MATLAB Fcn','champsat(u)',...
		'Output Width','3',...
		'position',[560,143,620,177])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Prcession vers soleil /Champ magntique',13,'en axes satellite_/Equateur au temps 0 s']])
set_param([sys,'/',['F(X,t) pour la rotation/Prcession vers soleil /Champ magntique',13,'en axes satellite_/Equateur au temps 0 s']],...
		'position',[150,75,155,80])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Prcession vers soleil /Champ magntique',13,'en axes satellite_/BX BY BZ']])
set_param([sys,'/',['F(X,t) pour la rotation/Prcession vers soleil /Champ magntique',13,'en axes satellite_/BX BY BZ']],...
		'position',[340,70,345,75])

add_block('built-in/Clock',[sys,'/',['F(X,t) pour la rotation/Prcession vers soleil /Champ magntique',13,'en axes satellite_/Clock']])
set_param([sys,'/',['F(X,t) pour la rotation/Prcession vers soleil /Champ magntique',13,'en axes satellite_/Clock']],...
		'position',[180,104,215,136])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Prcession vers soleil /Champ magntique',13,'en axes satellite_/MATLAB Fcn3']])
set_param([sys,'/',['F(X,t) pour la rotation/Prcession vers soleil /Champ magntique',13,'en axes satellite_/MATLAB Fcn3']],...
		'hide name',0,...
		'MATLAB Fcn','champmgn(u)',...
		'Output Width','3')
set_param([sys,'/',['F(X,t) pour la rotation/Prcession vers soleil /Champ magntique',13,'en axes satellite_/MATLAB Fcn3']],...
		'Mask Display','CHAMP MAGNETIQUE\nREPERE ORBITAL',...
		'position',[250,95,425,145])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Prcession vers soleil /Champ magntique',13,'en axes satellite_/Axes satellite']])
set_param([sys,'/',['F(X,t) pour la rotation/Prcession vers soleil /Champ magntique',13,'en axes satellite_/Axes satellite']],...
		'position',[710,115,715,120])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Prcession vers soleil /Champ magntique',13,'en axes satellite_/Sortie Bx By Bz']])
set_param([sys,'/',['F(X,t) pour la rotation/Prcession vers soleil /Champ magntique',13,'en axes satellite_/Sortie Bx By Bz']],...
		'position',[715,95,720,100])

add_block('built-in/Outport',[sys,'/',['F(X,t) pour la rotation/Prcession vers soleil /Champ magntique',13,'en axes satellite_/out_1']])
set_param([sys,'/',['F(X,t) pour la rotation/Prcession vers soleil /Champ magntique',13,'en axes satellite_/out_1']],...
		'position',[720,150,740,170])

add_block('built-in/Inport',[sys,'/',['F(X,t) pour la rotation/Prcession vers soleil /Champ magntique',13,'en axes satellite_/in_1']])
set_param([sys,'/',['F(X,t) pour la rotation/Prcession vers soleil /Champ magntique',13,'en axes satellite_/in_1']],...
		'position',[140,190,160,210])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Prcession vers soleil /Champ magntique',13,'en axes satellite_/Vecteur d''tat ',13,'7 composantes',13,'pqrQ)']])
set_param([sys,'/',['F(X,t) pour la rotation/Prcession vers soleil /Champ magntique',13,'en axes satellite_/Vecteur d''tat ',13,'7 composantes',13,'pqrQ)']],...
		'position',[140,235,145,240])
add_line([sys,'/',['F(X,t) pour la rotation/Prcession vers soleil /Champ magntique',13,'en axes satellite_']],[535,160;555,160])
add_line([sys,'/',['F(X,t) pour la rotation/Prcession vers soleil /Champ magntique',13,'en axes satellite_']],[165,200;480,200])
add_line([sys,'/',['F(X,t) pour la rotation/Prcession vers soleil /Champ magntique',13,'en axes satellite_']],[625,160;715,160])
add_line([sys,'/',['F(X,t) pour la rotation/Prcession vers soleil /Champ magntique',13,'en axes satellite_']],[430,120;480,120])
add_line([sys,'/',['F(X,t) pour la rotation/Prcession vers soleil /Champ magntique',13,'en axes satellite_']],[220,120;245,120])
set_param([sys,'/',['F(X,t) pour la rotation/Prcession vers soleil /Champ magntique',13,'en axes satellite_']],...
		'Mask Display','CHAMP MAGNETIQUE EN\nAXES SATELLITE\nEntre=vecteur d''tat\nSortie Bx By Bz')


%     Finished composite block ['F(X,t) pour la rotation/Prcession vers soleil /Champ magntique',13,'en axes satellite_'].

set_param([sys,'/',['F(X,t) pour la rotation/Prcession vers soleil /Champ magntique',13,'en axes satellite_']],...
		'position',[90,333,275,407])


%     Subsystem  'F(X,t) pour la rotation/Prcession vers soleil /Mz'.

new_system([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Mz'])
set_param([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Mz'],'Location',[4,44,660,311])

add_block('built-in/MATLAB Fcn',[sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Mz/Calcul de Mz '])
set_param([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Mz/Calcul de Mz '],...
		'MATLAB Fcn','Mz_Steyn(u)',...
		'Output Width','1',...
		'Mask Display','Calcul de Mz\navec saturation',...
		'position',[165,141,320,189])

add_block('built-in/MATLAB Fcn',[sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Mz/MATLAB Fcn2'])
set_param([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Mz/MATLAB Fcn2'],...
		'hide name',0,...
		'MATLAB Fcn','(u-temps_phase2)>0',...
		'Output Width','1',...
		'position',[185,83,245,117])

add_block('built-in/Clock',[sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Mz/Clock'])
set_param([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Mz/Clock'],...
		'position',[100,82,135,118])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Mz/Arrt de la premire phase'])
set_param([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Mz/Arrt de la premire phase'],...
		'position',[165,45,170,50])

add_block('built-in/Product',[sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Mz/Product'])
set_param([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Mz/Product'],...
		'position',[375,69,400,196])

add_block('built-in/Outport',[sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Mz/out_1'])
set_param([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Mz/out_1'],...
		'position',[430,125,450,145])

add_block('built-in/Inport',[sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Mz/in_1'])
set_param([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Mz/in_1'],...
		'position',[115,155,135,175])
add_line([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Mz'],[325,165;370,165])
add_line([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Mz'],[140,100;180,100])
add_line([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Mz'],[250,100;370,100])
add_line([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Mz'],[405,135;425,135])
add_line([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Mz'],[140,165;160,165])
set_param([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Mz'],...
		'Mask Display','Calcul de Mz avec\ndclenchement dcal\nsans saturation\naprs regroupement')


%     Finished composite block 'F(X,t) pour la rotation/Prcession vers soleil /Mz'.

set_param([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Mz'],...
		'position',[430,425,580,485])


%     Subsystem  'F(X,t) pour la rotation/Prcession vers soleil /Mx'.

new_system([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Mx'])
set_param([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Mx'],'Location',[323,557,843,802])

add_block('built-in/MATLAB Fcn',[sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Mx/Calcul de Mx  '])
set_param([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Mx/Calcul de Mx  '],...
		'MATLAB Fcn','Mx_Steyn(u)',...
		'Output Width','1',...
		'Mask Display','Calcul de Mx\nsans saturation',...
		'position',[165,141,320,189])

add_block('built-in/MATLAB Fcn',[sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Mx/MATLAB Fcn2'])
set_param([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Mx/MATLAB Fcn2'],...
		'hide name',0,...
		'MATLAB Fcn','(u-temps_phase2)>0',...
		'Output Width','1',...
		'position',[185,83,245,117])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Mx/Arrt de la premire phase'])
set_param([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Mx/Arrt de la premire phase'],...
		'position',[165,45,170,50])

add_block('built-in/Product',[sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Mx/Product'])
set_param([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Mx/Product'],...
		'position',[375,69,400,196])

add_block('built-in/Outport',[sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Mx/out_1'])
set_param([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Mx/out_1'],...
		'position',[430,125,450,145])

add_block('built-in/Inport',[sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Mx/in_1'])
set_param([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Mx/in_1'],...
		'position',[115,155,135,175])

add_block('built-in/Clock',[sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Mx/Clock'])
set_param([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Mx/Clock'],...
		'position',[100,82,135,118])
add_line([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Mx'],[325,165;370,165])
add_line([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Mx'],[140,100;180,100])
add_line([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Mx'],[250,100;370,100])
add_line([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Mx'],[405,135;425,135])
add_line([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Mx'],[140,165;160,165])
set_param([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Mx'],...
		'Mask Display','Calcul de M avec\ndclenchement dcal\nsans saturation\naprs regroupement')


%     Finished composite block 'F(X,t) pour la rotation/Prcession vers soleil /Mx'.

set_param([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Mx'],...
		'position',[430,249,580,311])

add_block('built-in/Sum',[sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Sum1'])
set_param([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Sum1'],...
		'position',[675,419,695,466])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Prcession vers soleil /Couple magntique',13,'2']])
set_param([sys,'/',['F(X,t) pour la rotation/Prcession vers soleil /Couple magntique',13,'2']],...
		'orientation',2,...
		'hide name',0,...
		'MATLAB Fcn','norm(u)',...
		'Output Width','1',...
		'position',[965,576,1055,614])

add_block('built-in/To Workspace',[sys,'/','F(X,t) pour la rotation/Prcession vers soleil /To Workspace1'])
set_param([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /To Workspace1'],...
		'orientation',2,...
		'hide name',0,...
		'mat-name','norme_cpl_steyn',...
		'buffer','points_trace',...
		'position',[830,584,930,606])

add_block('built-in/Mux',[sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Mux2'])
set_param([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Mux2'],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[775,338,795,467])

add_block('built-in/Mux',[sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Mux1'])
set_param([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Mux1'],...
		'hide name',0,...
		'inputs','3',...
		'position',[725,306,745,434])

add_block('built-in/Sum',[sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Sum'])
set_param([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Sum'],...
		'position',[680,269,700,316])

add_block('built-in/Demux',[sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Demux'])
set_param([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Demux'],...
		'outputs','3',...
		'position',[600,354,640,386])


%     Subsystem  'F(X,t) pour la rotation/Prcession vers soleil /Calcul de My'.

new_system([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Calcul de My'])
set_param([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Calcul de My'],'Location',[4,44,1268,968])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Calcul de My/CALCUL DU MOMENT MAGNETIQUE OPTIMISE ( partir de My) AVEC SATURATION '])
set_param([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Calcul de My/CALCUL DU MOMENT MAGNETIQUE OPTIMISE ( partir de My) AVEC SATURATION '],...
		'Font Name','Arial Narrow',...
		'Font Size',18,...
		'position',[625,35,630,40])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Calcul de My/Vecteur champ'])
set_param([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Calcul de My/Vecteur champ'],...
		'position',[435,475,440,480])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Prcession vers soleil /Calcul de My/beta',13,'prime']])
set_param([sys,'/',['F(X,t) pour la rotation/Prcession vers soleil /Calcul de My/beta',13,'prime']],...
		'position',[405,295,410,300])

add_block('built-in/Derivative',[sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Calcul de My/Derivative'])
set_param([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Calcul de My/Derivative'],...
		'hide name',0,...
		'position',[375,343,425,377])

add_block('built-in/MATLAB Fcn',[sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Calcul de My/MATLAB Fcn'])
set_param([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Calcul de My/MATLAB Fcn'],...
		'hide name',0,...
		'MATLAB Fcn','beta_tg(u)',...
		'Output Width','1',...
		'Mask Display','beta_tg',...
		'position',[260,343,320,377])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Prcession vers soleil /Calcul de My/Moment magntique',13,'brut avant optimisation']])
set_param([sys,'/',['F(X,t) pour la rotation/Prcession vers soleil /Calcul de My/Moment magntique',13,'brut avant optimisation']],...
		'position',[585,260,590,265])

add_block('built-in/Constant',[sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Calcul de My/Constant2'])
set_param([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Calcul de My/Constant2'],...
		'hide name',0,...
		'Value','0',...
		'position',[545,325,565,345])

add_block('built-in/Constant',[sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Calcul de My/Constant3'])
set_param([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Calcul de My/Constant3'],...
		'hide name',0,...
		'Value','0',...
		'position',[545,375,565,395])

add_block('built-in/Mux',[sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Calcul de My/Mux5'])
set_param([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Calcul de My/Mux5'],...
		'hide name',0,...
		'inputs','3',...
		'position',[580,320,610,400])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Prcession vers soleil /Calcul de My/My',13,'vecteur1']])
set_param([sys,'/',['F(X,t) pour la rotation/Prcession vers soleil /Calcul de My/My',13,'vecteur1']],...
		'position',[595,395,600,400])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Calcul de My/B'])
set_param([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Calcul de My/B'],...
		'hide name',0,...
		'position',[485,440,490,445])

add_block('built-in/Gain',[sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Calcul de My/Gain1'])
set_param([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Calcul de My/Gain1'],...
		'hide name',0,...
		'Gain','180/pi',...
		'position',[410,416,465,454])

add_block('built-in/To Workspace',[sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Calcul de My/To Workspace3'])
set_param([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Calcul de My/To Workspace3'],...
		'hide name',0,...
		'mat-name','beta_steyn',...
		'buffer','points_trace',...
		'position',[480,425,560,445])

add_block('built-in/Gain',[sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Calcul de My/Gain'])
set_param([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Calcul de My/Gain'],...
		'hide name',0,...
		'Gain','K_beta',...
		'position',[475,346,520,374])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Calcul de My/beta et beta_prime'])
set_param([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Calcul de My/beta et beta_prime'],...
		'hide name',0,...
		'position',[425,310,430,315])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Calcul de My/B  '])
set_param([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Calcul de My/B  '],...
		'position',[180,315,185,320])

add_block('built-in/Inport',[sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Calcul de My/in_1'])
set_param([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Calcul de My/in_1'],...
		'position',[160,350,180,370])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Calcul de My/Vecteur 3 composantes'])
set_param([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Calcul de My/Vecteur 3 composantes'],...
		'position',[730,435,735,440])

add_block('built-in/To Workspace',[sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Calcul de My/To Workspace2'])
set_param([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Calcul de My/To Workspace2'],...
		'hide name',0,...
		'mat-name','M_beta',...
		'buffer','points_trace',...
		'position',[695,410,775,430])

add_block('built-in/Outport',[sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Calcul de My/out_1'])
set_param([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Calcul de My/out_1'],...
		'position',[745,350,765,370])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Prcession vers soleil /Calcul de My/Sortie du moment',13,'magntique My',13,'']])
set_param([sys,'/',['F(X,t) pour la rotation/Prcession vers soleil /Calcul de My/Sortie du moment',13,'magntique My',13,'']],...
		'position',[740,285,745,290])
add_line([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Calcul de My'],[325,360;325,435;405,435])
add_line([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Calcul de My'],[470,435;475,435])
add_line([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Calcul de My'],[325,360;370,360])
add_line([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Calcul de My'],[430,360;470,360])
add_line([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Calcul de My'],[615,360;740,360])
add_line([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Calcul de My'],[665,360;665,420;690,420])
add_line([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Calcul de My'],[185,360;255,360])
add_line([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Calcul de My'],[570,335;575,335])
add_line([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Calcul de My'],[570,385;575,385])
add_line([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Calcul de My'],[525,360;575,360])
set_param([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Calcul de My'],...
		'Mask Display','Calcul de My\ncommande de Steyn\navec l''angle beta driv')


%     Finished composite block 'F(X,t) pour la rotation/Prcession vers soleil /Calcul de My'.

set_param([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Calcul de My'],...
		'position',[425,332,580,408])

add_block('built-in/Mux',[sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Mux3'])
set_param([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Mux3'],...
		'hide name',0,...
		'inputs','[3 7 1]',...
		'position',[360,411,395,499])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Prcession vers soleil /Couple',13,' magntique']])
set_param([sys,'/',['F(X,t) pour la rotation/Prcession vers soleil /Couple',13,' magntique']],...
		'position',[1055,375,1060,380])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Prcession vers soleil /Couple magntique',13,'1']])
set_param([sys,'/',['F(X,t) pour la rotation/Prcession vers soleil /Couple magntique',13,'1']],...
		'hide name',0,...
		'MATLAB Fcn','magn_sat(u)',...
		'Output Width','3',...
		'position',[815,351,905,389])

add_block('built-in/Mux',[sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Mux4'])
set_param([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Mux4'],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[950,303,985,567])

add_block('built-in/To Workspace',[sys,'/','F(X,t) pour la rotation/Prcession vers soleil /To Workspace7'])
set_param([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /To Workspace7'],...
		'hide name',0,...
		'mat-name','Mz',...
		'buffer','points_trace',...
		'position',[1100,289,1135,311])

add_block('built-in/To Workspace',[sys,'/','F(X,t) pour la rotation/Prcession vers soleil /To Workspace8'])
set_param([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /To Workspace8'],...
		'hide name',0,...
		'mat-name','My',...
		'buffer','points_trace',...
		'position',[1100,264,1135,286])

add_block('built-in/To Workspace',[sys,'/','F(X,t) pour la rotation/Prcession vers soleil /To Workspace2'])
set_param([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /To Workspace2'],...
		'hide name',0,...
		'mat-name','Mx',...
		'buffer','points_trace',...
		'position',[1100,239,1135,261])

add_block('built-in/Demux',[sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Demux1'])
set_param([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Demux1'],...
		'outputs','3',...
		'position',[1005,238,1050,312])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Prcession vers soleil /Couple magntique',13,'']])
set_param([sys,'/',['F(X,t) pour la rotation/Prcession vers soleil /Couple magntique',13,'']],...
		'hide name',0,...
		'MATLAB Fcn','prodvect(u)',...
		'Output Width','3',...
		'position',[1020,416,1110,454])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Prcession vers soleil /Couple de',13,'Steyn gnral']])
set_param([sys,'/',['F(X,t) pour la rotation/Prcession vers soleil /Couple de',13,'Steyn gnral']],...
		'position',[1195,305,1200,310])

add_block('built-in/To Workspace',[sys,'/','F(X,t) pour la rotation/Prcession vers soleil /To Workspace'])
set_param([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /To Workspace'],...
		'hide name',0,...
		'mat-name','cpl_steyn',...
		'buffer','points_trace',...
		'position',[1160,355,1240,375])

add_block('built-in/Outport',[sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Outport1'])
set_param([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Outport1'],...
		'hide name',0,...
		'position',[1275,425,1295,445])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Le moment My agit en permanence'])
set_param([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Le moment My agit en permanence'],...
		'position',[620,160,625,165])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Prcession vers soleil /Les moments Mx et Mz n''agissent qu'' partir de temps_phase2 et cessent  temps_phase3']])
set_param([sys,'/',['F(X,t) pour la rotation/Prcession vers soleil /Les moments Mx et Mz n''agissent qu'' partir de temps_phase2 et cessent  temps_phase3']],...
		'position',[570,130,575,135])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Prcession vers soleil /Sortie B',13,'axes satellite']])
set_param([sys,'/',['F(X,t) pour la rotation/Prcession vers soleil /Sortie B',13,'axes satellite']],...
		'hide name',0,...
		'position',[190,280,195,285])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Prcession vers soleil /Entre vecteur d''tat ',13,'7 composantes p q r Q']])
set_param([sys,'/',['F(X,t) pour la rotation/Prcession vers soleil /Entre vecteur d''tat ',13,'7 composantes p q r Q']],...
		'hide name',0,...
		'position',[40,450,45,455])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/Prcession vers soleil /pqrQ'])
set_param([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /pqrQ'],...
		'position',[185,450,190,455])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Les moments magntiques sont limits  0.2 A-m, aprs regroupement des 3 moments magntiques'])
set_param([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /Les moments magntiques sont limits  0.2 A-m, aprs regroupement des 3 moments magntiques'],...
		'position',[590,105,595,110])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Prcession vers soleil /NB : Dans le vol rel, le champ magntique est celui ',13,'mesur par les magntomtres et filtr  la position du satellite']])
set_param([sys,'/',['F(X,t) pour la rotation/Prcession vers soleil /NB : Dans le vol rel, le champ magntique est celui ',13,'mesur par les magntomtres et filtr  la position du satellite']],...
		'ForeGround',2,...
		'Font Name','Arial')
set_param([sys,'/',['F(X,t) pour la rotation/Prcession vers soleil /NB : Dans le vol rel, le champ magntique est celui ',13,'mesur par les magntomtres et filtr  la position du satellite']],...
		'Font Size',14)
set_param([sys,'/',['F(X,t) pour la rotation/Prcession vers soleil /NB : Dans le vol rel, le champ magntique est celui ',13,'mesur par les magntomtres et filtr  la position du satellite']],...
		'position',[620,47,625,52])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Prcession vers soleil /REGULATION PAR LA DERIVEE DE L''ANGLE Beta ET UN GAIN  K_beta']])
set_param([sys,'/',['F(X,t) pour la rotation/Prcession vers soleil /REGULATION PAR LA DERIVEE DE L''ANGLE Beta ET UN GAIN  K_beta']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',18,...
		'position',[645,10,650,15])

add_block('built-in/Inport',[sys,'/','F(X,t) pour la rotation/Prcession vers soleil /in_1'])
set_param([sys,'/','F(X,t) pour la rotation/Prcession vers soleil /in_1'],...
		'hide name',0,...
		'position',[10,360,25,380])
add_line([sys,'/','F(X,t) pour la rotation/Prcession vers soleil '],[30,370;85,370])
add_line([sys,'/','F(X,t) pour la rotation/Prcession vers soleil '],[55,370;55,455;355,455])
add_line([sys,'/','F(X,t) pour la rotation/Prcession vers soleil '],[280,370;295,370;295,500;945,500])
add_line([sys,'/','F(X,t) pour la rotation/Prcession vers soleil '],[1115,435;1240,435;1250,425;1250,435;1270,435])
add_line([sys,'/','F(X,t) pour la rotation/Prcession vers soleil '],[280,370;420,370])
add_line([sys,'/','F(X,t) pour la rotation/Prcession vers soleil '],[255,485;355,485])
add_line([sys,'/','F(X,t) pour la rotation/Prcession vers soleil '],[400,455;400,280;425,280])
add_line([sys,'/','F(X,t) pour la rotation/Prcession vers soleil '],[585,455;670,455])
add_line([sys,'/','F(X,t) pour la rotation/Prcession vers soleil '],[400,455;425,455])
add_line([sys,'/','F(X,t) pour la rotation/Prcession vers soleil '],[990,435;1015,435])
add_line([sys,'/','F(X,t) pour la rotation/Prcession vers soleil '],[1115,435;1115,365;1155,365])
add_line([sys,'/','F(X,t) pour la rotation/Prcession vers soleil '],[585,370;595,370])
add_line([sys,'/','F(X,t) pour la rotation/Prcession vers soleil '],[585,280;675,280])
add_line([sys,'/','F(X,t) pour la rotation/Prcession vers soleil '],[645,360;665,360;675,305])
add_line([sys,'/','F(X,t) pour la rotation/Prcession vers soleil '],[645,380;654,380;655,430;670,430])
add_line([sys,'/','F(X,t) pour la rotation/Prcession vers soleil '],[705,295;705,330;720,330])
add_line([sys,'/','F(X,t) pour la rotation/Prcession vers soleil '],[645,370;720,370])
add_line([sys,'/','F(X,t) pour la rotation/Prcession vers soleil '],[700,445;700,410;720,410])
add_line([sys,'/','F(X,t) pour la rotation/Prcession vers soleil '],[910,370;945,370])
add_line([sys,'/','F(X,t) pour la rotation/Prcession vers soleil '],[910,370;910,275;1000,275])
add_line([sys,'/','F(X,t) pour la rotation/Prcession vers soleil '],[1055,250;1095,250])
add_line([sys,'/','F(X,t) pour la rotation/Prcession vers soleil '],[1055,275;1095,275])
add_line([sys,'/','F(X,t) pour la rotation/Prcession vers soleil '],[1055,300;1095,300])
add_line([sys,'/','F(X,t) pour la rotation/Prcession vers soleil '],[800,405;810,370])
add_line([sys,'/','F(X,t) pour la rotation/Prcession vers soleil '],[750,370;770,370])
add_line([sys,'/','F(X,t) pour la rotation/Prcession vers soleil '],[755,500;755,435;770,435])
add_line([sys,'/','F(X,t) pour la rotation/Prcession vers soleil '],[960,595;935,595])
add_line([sys,'/','F(X,t) pour la rotation/Prcession vers soleil '],[1115,435;1115,595;1060,595])
add_line([sys,'/','F(X,t) pour la rotation/Prcession vers soleil '],[295,425;355,425])
set_param([sys,'/','F(X,t) pour la rotation/Prcession vers soleil '],...
		'Mask Display','PRECESSION \nDE\nVERS LE SOLEIL')


%     Finished composite block 'F(X,t) pour la rotation/Prcession vers soleil '.

set_param([sys,'/','F(X,t) pour la rotation/Prcession vers soleil '],...
		'position',[155,129,375,211])

add_block('built-in/Sum',[sys,'/','F(X,t) pour la rotation/Sum2'])
set_param([sys,'/','F(X,t) pour la rotation/Sum2'],...
		'position',[925,61,970,274])


%     Subsystem  'F(X,t) pour la rotation/Rgulation tumbling de Steyn'.

new_system([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn'],'Location',[-32000,-32000,-31840,-31975])

add_block('built-in/Clock',[sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Clock'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Clock'],...
		'position',[215,467,250,503])


%     Subsystem  ['F(X,t) pour la rotation/Rgulation tumbling de Steyn/Champ magntique',13,'en axes satellite_'].

new_system([sys,'/',['F(X,t) pour la rotation/Rgulation tumbling de Steyn/Champ magntique',13,'en axes satellite_']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation tumbling de Steyn/Champ magntique',13,'en axes satellite_']],'Location',[59,535,1014,1004])

add_block('built-in/Mux',[sys,'/',['F(X,t) pour la rotation/Rgulation tumbling de Steyn/Champ magntique',13,'en axes satellite_/Mux1']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation tumbling de Steyn/Champ magntique',13,'en axes satellite_/Mux1']],...
		'inputs','[3 7]',...
		'position',[485,80,530,240])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Rgulation tumbling de Steyn/Champ magntique',13,'en axes satellite_/MATLAB Fcn1']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation tumbling de Steyn/Champ magntique',13,'en axes satellite_/MATLAB Fcn1']],...
		'MATLAB Fcn','champsat(u)',...
		'Output Width','3',...
		'position',[560,143,620,177])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Rgulation tumbling de Steyn/Champ magntique',13,'en axes satellite_/Equateur au temps 0 s']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation tumbling de Steyn/Champ magntique',13,'en axes satellite_/Equateur au temps 0 s']],...
		'position',[150,75,155,80])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Rgulation tumbling de Steyn/Champ magntique',13,'en axes satellite_/BX BY BZ']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation tumbling de Steyn/Champ magntique',13,'en axes satellite_/BX BY BZ']],...
		'position',[340,70,345,75])

add_block('built-in/Clock',[sys,'/',['F(X,t) pour la rotation/Rgulation tumbling de Steyn/Champ magntique',13,'en axes satellite_/Clock']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation tumbling de Steyn/Champ magntique',13,'en axes satellite_/Clock']],...
		'position',[180,104,215,136])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Rgulation tumbling de Steyn/Champ magntique',13,'en axes satellite_/MATLAB Fcn3']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation tumbling de Steyn/Champ magntique',13,'en axes satellite_/MATLAB Fcn3']],...
		'hide name',0,...
		'MATLAB Fcn','champmgn(u)',...
		'Output Width','3')
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation tumbling de Steyn/Champ magntique',13,'en axes satellite_/MATLAB Fcn3']],...
		'Mask Display','CHAMP MAGNETIQUE\nREPERE ORBITAL',...
		'position',[250,95,425,145])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Rgulation tumbling de Steyn/Champ magntique',13,'en axes satellite_/Axes satellite']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation tumbling de Steyn/Champ magntique',13,'en axes satellite_/Axes satellite']],...
		'position',[710,115,715,120])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Rgulation tumbling de Steyn/Champ magntique',13,'en axes satellite_/Sortie Bx By Bz']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation tumbling de Steyn/Champ magntique',13,'en axes satellite_/Sortie Bx By Bz']],...
		'position',[715,95,720,100])

add_block('built-in/Outport',[sys,'/',['F(X,t) pour la rotation/Rgulation tumbling de Steyn/Champ magntique',13,'en axes satellite_/out_1']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation tumbling de Steyn/Champ magntique',13,'en axes satellite_/out_1']],...
		'position',[720,150,740,170])

add_block('built-in/Inport',[sys,'/',['F(X,t) pour la rotation/Rgulation tumbling de Steyn/Champ magntique',13,'en axes satellite_/in_1']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation tumbling de Steyn/Champ magntique',13,'en axes satellite_/in_1']],...
		'position',[140,190,160,210])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Rgulation tumbling de Steyn/Champ magntique',13,'en axes satellite_/Vecteur d''tat ',13,'7 composantes',13,'pqrQ)']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation tumbling de Steyn/Champ magntique',13,'en axes satellite_/Vecteur d''tat ',13,'7 composantes',13,'pqrQ)']],...
		'position',[140,235,145,240])
add_line([sys,'/',['F(X,t) pour la rotation/Rgulation tumbling de Steyn/Champ magntique',13,'en axes satellite_']],[535,160;555,160])
add_line([sys,'/',['F(X,t) pour la rotation/Rgulation tumbling de Steyn/Champ magntique',13,'en axes satellite_']],[165,200;480,200])
add_line([sys,'/',['F(X,t) pour la rotation/Rgulation tumbling de Steyn/Champ magntique',13,'en axes satellite_']],[625,160;715,160])
add_line([sys,'/',['F(X,t) pour la rotation/Rgulation tumbling de Steyn/Champ magntique',13,'en axes satellite_']],[430,120;480,120])
add_line([sys,'/',['F(X,t) pour la rotation/Rgulation tumbling de Steyn/Champ magntique',13,'en axes satellite_']],[220,120;245,120])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation tumbling de Steyn/Champ magntique',13,'en axes satellite_']],...
		'Mask Display','CHAMP MAGNETIQUE EN\nAXES SATELLITE\nEntre=vecteur d''tat\nSortie Bx By Bz')


%     Finished composite block ['F(X,t) pour la rotation/Rgulation tumbling de Steyn/Champ magntique',13,'en axes satellite_'].

set_param([sys,'/',['F(X,t) pour la rotation/Rgulation tumbling de Steyn/Champ magntique',13,'en axes satellite_']],...
		'position',[90,333,275,407])


%     Subsystem  'F(X,t) pour la rotation/Rgulation tumbling de Steyn/Mz'.

new_system([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Mz'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Mz'],'Location',[4,44,660,311])

add_block('built-in/MATLAB Fcn',[sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Mz/Calcul de Mz '])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Mz/Calcul de Mz '],...
		'MATLAB Fcn','Mz_Steyn(u)',...
		'Output Width','1',...
		'Mask Display','Calcul de Mz\navec saturation',...
		'position',[165,141,320,189])

add_block('built-in/MATLAB Fcn',[sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Mz/MATLAB Fcn2'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Mz/MATLAB Fcn2'],...
		'hide name',0,...
		'MATLAB Fcn','(u-temps_phase2)>0',...
		'Output Width','1',...
		'position',[185,83,245,117])

add_block('built-in/Clock',[sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Mz/Clock'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Mz/Clock'],...
		'position',[100,82,135,118])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Mz/Arrt de la premire phase'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Mz/Arrt de la premire phase'],...
		'position',[165,45,170,50])

add_block('built-in/Product',[sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Mz/Product'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Mz/Product'],...
		'position',[375,69,400,196])

add_block('built-in/Outport',[sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Mz/out_1'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Mz/out_1'],...
		'position',[430,125,450,145])

add_block('built-in/Inport',[sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Mz/in_1'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Mz/in_1'],...
		'position',[115,155,135,175])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Mz'],[325,165;370,165])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Mz'],[140,100;180,100])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Mz'],[250,100;370,100])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Mz'],[405,135;425,135])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Mz'],[140,165;160,165])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Mz'],...
		'Mask Display','Calcul de Mz avec\ndclenchement dcal\nsans saturation\naprs regroupement')


%     Finished composite block 'F(X,t) pour la rotation/Rgulation tumbling de Steyn/Mz'.

set_param([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Mz'],...
		'position',[430,425,580,485])


%     Subsystem  'F(X,t) pour la rotation/Rgulation tumbling de Steyn/Mx'.

new_system([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Mx'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Mx'],'Location',[323,557,843,802])

add_block('built-in/MATLAB Fcn',[sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Mx/Calcul de Mx  '])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Mx/Calcul de Mx  '],...
		'MATLAB Fcn','Mx_Steyn(u)',...
		'Output Width','1',...
		'Mask Display','Calcul de Mx\nsans saturation',...
		'position',[165,141,320,189])

add_block('built-in/MATLAB Fcn',[sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Mx/MATLAB Fcn2'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Mx/MATLAB Fcn2'],...
		'hide name',0,...
		'MATLAB Fcn','(u-temps_phase2)>0',...
		'Output Width','1',...
		'position',[185,83,245,117])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Mx/Arrt de la premire phase'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Mx/Arrt de la premire phase'],...
		'position',[165,45,170,50])

add_block('built-in/Product',[sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Mx/Product'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Mx/Product'],...
		'position',[375,69,400,196])

add_block('built-in/Outport',[sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Mx/out_1'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Mx/out_1'],...
		'position',[430,125,450,145])

add_block('built-in/Inport',[sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Mx/in_1'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Mx/in_1'],...
		'position',[115,155,135,175])

add_block('built-in/Clock',[sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Mx/Clock'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Mx/Clock'],...
		'position',[100,82,135,118])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Mx'],[325,165;370,165])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Mx'],[140,100;180,100])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Mx'],[250,100;370,100])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Mx'],[405,135;425,135])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Mx'],[140,165;160,165])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Mx'],...
		'Mask Display','Calcul de M avec\ndclenchement dcal\nsans saturation\naprs regroupement')


%     Finished composite block 'F(X,t) pour la rotation/Rgulation tumbling de Steyn/Mx'.

set_param([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Mx'],...
		'position',[430,249,580,311])

add_block('built-in/Sum',[sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Sum1'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Sum1'],...
		'position',[675,419,695,466])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Rgulation tumbling de Steyn/Couple magntique',13,'2']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation tumbling de Steyn/Couple magntique',13,'2']],...
		'orientation',2,...
		'hide name',0,...
		'MATLAB Fcn','norm(u)',...
		'Output Width','1',...
		'position',[965,576,1055,614])

add_block('built-in/To Workspace',[sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/To Workspace1'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/To Workspace1'],...
		'orientation',2,...
		'hide name',0,...
		'mat-name','norme_cpl_steyn',...
		'buffer','points_trace',...
		'position',[830,584,930,606])

add_block('built-in/Mux',[sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Mux2'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Mux2'],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[775,338,795,467])

add_block('built-in/Mux',[sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Mux1'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Mux1'],...
		'hide name',0,...
		'inputs','3',...
		'position',[725,306,745,434])

add_block('built-in/Sum',[sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Sum'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Sum'],...
		'position',[680,269,700,316])

add_block('built-in/Demux',[sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Demux'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Demux'],...
		'outputs','3',...
		'position',[600,354,640,386])


%     Subsystem  'F(X,t) pour la rotation/Rgulation tumbling de Steyn/Calcul de My'.

new_system([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Calcul de My'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Calcul de My'],'Location',[4,44,1268,968])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Calcul de My/CALCUL DU MOMENT MAGNETIQUE OPTIMISE ( partir de My) AVEC SATURATION '])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Calcul de My/CALCUL DU MOMENT MAGNETIQUE OPTIMISE ( partir de My) AVEC SATURATION '],...
		'Font Name','Arial Narrow',...
		'Font Size',18,...
		'position',[625,35,630,40])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Calcul de My/Vecteur champ'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Calcul de My/Vecteur champ'],...
		'position',[435,475,440,480])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Rgulation tumbling de Steyn/Calcul de My/beta',13,'prime']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation tumbling de Steyn/Calcul de My/beta',13,'prime']],...
		'position',[405,295,410,300])

add_block('built-in/Derivative',[sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Calcul de My/Derivative'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Calcul de My/Derivative'],...
		'hide name',0,...
		'position',[375,343,425,377])

add_block('built-in/MATLAB Fcn',[sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Calcul de My/MATLAB Fcn'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Calcul de My/MATLAB Fcn'],...
		'hide name',0,...
		'MATLAB Fcn','beta_tg(u)',...
		'Output Width','1',...
		'Mask Display','beta_tg',...
		'position',[260,343,320,377])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Rgulation tumbling de Steyn/Calcul de My/Moment magntique',13,'brut avant optimisation']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation tumbling de Steyn/Calcul de My/Moment magntique',13,'brut avant optimisation']],...
		'position',[585,260,590,265])

add_block('built-in/Constant',[sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Calcul de My/Constant2'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Calcul de My/Constant2'],...
		'hide name',0,...
		'Value','0',...
		'position',[545,325,565,345])

add_block('built-in/Constant',[sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Calcul de My/Constant3'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Calcul de My/Constant3'],...
		'hide name',0,...
		'Value','0',...
		'position',[545,375,565,395])

add_block('built-in/Mux',[sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Calcul de My/Mux5'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Calcul de My/Mux5'],...
		'hide name',0,...
		'inputs','3',...
		'position',[580,320,610,400])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Rgulation tumbling de Steyn/Calcul de My/My',13,'vecteur1']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation tumbling de Steyn/Calcul de My/My',13,'vecteur1']],...
		'position',[595,395,600,400])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Calcul de My/B'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Calcul de My/B'],...
		'hide name',0,...
		'position',[485,440,490,445])

add_block('built-in/Gain',[sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Calcul de My/Gain1'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Calcul de My/Gain1'],...
		'hide name',0,...
		'Gain','180/pi',...
		'position',[410,416,465,454])

add_block('built-in/To Workspace',[sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Calcul de My/To Workspace3'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Calcul de My/To Workspace3'],...
		'hide name',0,...
		'mat-name','beta_steyn',...
		'buffer','points_trace',...
		'position',[480,425,560,445])

add_block('built-in/Gain',[sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Calcul de My/Gain'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Calcul de My/Gain'],...
		'hide name',0,...
		'Gain','K_beta',...
		'position',[475,346,520,374])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Calcul de My/beta et beta_prime'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Calcul de My/beta et beta_prime'],...
		'hide name',0,...
		'position',[425,310,430,315])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Calcul de My/B  '])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Calcul de My/B  '],...
		'position',[180,315,185,320])

add_block('built-in/Inport',[sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Calcul de My/in_1'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Calcul de My/in_1'],...
		'position',[160,350,180,370])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Calcul de My/Vecteur 3 composantes'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Calcul de My/Vecteur 3 composantes'],...
		'position',[730,435,735,440])

add_block('built-in/To Workspace',[sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Calcul de My/To Workspace2'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Calcul de My/To Workspace2'],...
		'hide name',0,...
		'mat-name','M_beta',...
		'buffer','points_trace',...
		'position',[695,410,775,430])

add_block('built-in/Outport',[sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Calcul de My/out_1'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Calcul de My/out_1'],...
		'position',[745,350,765,370])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Rgulation tumbling de Steyn/Calcul de My/Sortie du moment',13,'magntique My',13,'']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation tumbling de Steyn/Calcul de My/Sortie du moment',13,'magntique My',13,'']],...
		'position',[740,285,745,290])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Calcul de My'],[325,360;325,435;405,435])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Calcul de My'],[470,435;475,435])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Calcul de My'],[325,360;370,360])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Calcul de My'],[430,360;470,360])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Calcul de My'],[615,360;740,360])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Calcul de My'],[665,360;665,420;690,420])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Calcul de My'],[185,360;255,360])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Calcul de My'],[570,335;575,335])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Calcul de My'],[570,385;575,385])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Calcul de My'],[525,360;575,360])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Calcul de My'],...
		'Mask Display','Calcul de My\ncommande de Steyn\navec l''angle beta driv')


%     Finished composite block 'F(X,t) pour la rotation/Rgulation tumbling de Steyn/Calcul de My'.

set_param([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Calcul de My'],...
		'position',[425,332,580,408])

add_block('built-in/Mux',[sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Mux3'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Mux3'],...
		'hide name',0,...
		'inputs','[3 7 1]',...
		'position',[360,411,395,499])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Rgulation tumbling de Steyn/Couple',13,' magntique']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation tumbling de Steyn/Couple',13,' magntique']],...
		'position',[1055,375,1060,380])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Rgulation tumbling de Steyn/Couple magntique',13,'1']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation tumbling de Steyn/Couple magntique',13,'1']],...
		'hide name',0,...
		'MATLAB Fcn','magn_sat(u)',...
		'Output Width','3',...
		'position',[815,351,905,389])

add_block('built-in/Mux',[sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Mux4'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Mux4'],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[950,303,985,567])

add_block('built-in/To Workspace',[sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/To Workspace7'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/To Workspace7'],...
		'hide name',0,...
		'mat-name','Mz',...
		'buffer','points_trace',...
		'position',[1100,289,1135,311])

add_block('built-in/To Workspace',[sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/To Workspace8'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/To Workspace8'],...
		'hide name',0,...
		'mat-name','My',...
		'buffer','points_trace',...
		'position',[1100,264,1135,286])

add_block('built-in/To Workspace',[sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/To Workspace2'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/To Workspace2'],...
		'hide name',0,...
		'mat-name','Mx',...
		'buffer','points_trace',...
		'position',[1100,239,1135,261])

add_block('built-in/Demux',[sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Demux1'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Demux1'],...
		'outputs','3',...
		'position',[1005,238,1050,312])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Rgulation tumbling de Steyn/Couple magntique',13,'']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation tumbling de Steyn/Couple magntique',13,'']],...
		'hide name',0,...
		'MATLAB Fcn','prodvect(u)',...
		'Output Width','3',...
		'position',[1020,416,1110,454])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Rgulation tumbling de Steyn/Couple de',13,'Steyn gnral']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation tumbling de Steyn/Couple de',13,'Steyn gnral']],...
		'position',[1195,305,1200,310])

add_block('built-in/To Workspace',[sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/To Workspace'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/To Workspace'],...
		'hide name',0,...
		'mat-name','cpl_steyn',...
		'buffer','points_trace',...
		'position',[1160,355,1240,375])

add_block('built-in/Outport',[sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Outport1'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Outport1'],...
		'hide name',0,...
		'position',[1275,425,1295,445])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Le moment My agit en permanence'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Le moment My agit en permanence'],...
		'position',[620,160,625,165])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Rgulation tumbling de Steyn/Les moments Mx et Mz n''agissent qu'' partir de temps_phase2 et cessent  temps_phase3']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation tumbling de Steyn/Les moments Mx et Mz n''agissent qu'' partir de temps_phase2 et cessent  temps_phase3']],...
		'position',[570,130,575,135])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Rgulation tumbling de Steyn/Sortie B',13,'axes satellite']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation tumbling de Steyn/Sortie B',13,'axes satellite']],...
		'hide name',0,...
		'position',[190,280,195,285])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Rgulation tumbling de Steyn/Entre vecteur d''tat ',13,'7 composantes p q r Q']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation tumbling de Steyn/Entre vecteur d''tat ',13,'7 composantes p q r Q']],...
		'hide name',0,...
		'position',[40,450,45,455])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/pqrQ'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/pqrQ'],...
		'position',[185,450,190,455])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Les moments magntiques sont limits  0.2 A-m, aprs regroupement des 3 moments magntiques'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/Les moments magntiques sont limits  0.2 A-m, aprs regroupement des 3 moments magntiques'],...
		'position',[590,105,595,110])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Rgulation tumbling de Steyn/NB : Dans le vol rel, le champ magntique est celui ',13,'mesur par les magntomtres et filtr  la position du satellite']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation tumbling de Steyn/NB : Dans le vol rel, le champ magntique est celui ',13,'mesur par les magntomtres et filtr  la position du satellite']],...
		'ForeGround',2)
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation tumbling de Steyn/NB : Dans le vol rel, le champ magntique est celui ',13,'mesur par les magntomtres et filtr  la position du satellite']],...
		'Font Name','Arial')
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation tumbling de Steyn/NB : Dans le vol rel, le champ magntique est celui ',13,'mesur par les magntomtres et filtr  la position du satellite']],...
		'Font Size',14)
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation tumbling de Steyn/NB : Dans le vol rel, le champ magntique est celui ',13,'mesur par les magntomtres et filtr  la position du satellite']],...
		'position',[620,47,625,52])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Rgulation tumbling de Steyn/REGULATION PAR LA DERIVEE DE L''ANGLE Beta ET UN GAIN  K_beta']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation tumbling de Steyn/REGULATION PAR LA DERIVEE DE L''ANGLE Beta ET UN GAIN  K_beta']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',18,...
		'position',[645,10,650,15])

add_block('built-in/Inport',[sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/in_1'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn/in_1'],...
		'hide name',0,...
		'position',[10,360,25,380])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn'],[30,370;85,370])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn'],[55,370;55,455;355,455])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn'],[280,370;295,370;295,500;945,500])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn'],[1115,435;1240,435;1250,425;1250,435;1270,435])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn'],[280,370;420,370])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn'],[255,485;355,485])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn'],[400,455;400,280;425,280])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn'],[585,455;670,455])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn'],[400,455;425,455])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn'],[990,435;1015,435])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn'],[1115,435;1115,365;1155,365])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn'],[585,370;595,370])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn'],[585,280;675,280])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn'],[645,360;665,360;675,305])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn'],[645,380;654,380;655,430;670,430])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn'],[705,295;705,330;720,330])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn'],[645,370;720,370])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn'],[700,445;700,410;720,410])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn'],[910,370;945,370])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn'],[910,370;910,275;1000,275])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn'],[1055,250;1095,250])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn'],[1055,275;1095,275])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn'],[1055,300;1095,300])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn'],[800,405;810,370])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn'],[750,370;770,370])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn'],[755,500;755,435;770,435])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn'],[960,595;935,595])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn'],[1115,435;1115,595;1060,595])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn'],[295,425;355,425])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn'],...
		'Mask Display','REGULATION TUMBLING \nDE\nSTEYN')


%     Finished composite block 'F(X,t) pour la rotation/Rgulation tumbling de Steyn'.

set_param([sys,'/','F(X,t) pour la rotation/Rgulation tumbling de Steyn'],...
		'position',[155,239,375,321])

add_block('built-in/Switch',[sys,'/','F(X,t) pour la rotation/Switch'])
set_param([sys,'/','F(X,t) pour la rotation/Switch'],...
		'Threshold','0.5',...
		'position',[545,145,570,305])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/En clipse'])
set_param([sys,'/','F(X,t) pour la rotation/En clipse'],...
		'position',[445,280,450,285])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/Hors clipse'])
set_param([sys,'/','F(X,t) pour la rotation/Hors clipse'],...
		'position',[440,140,445,145])
add_line([sys,'/','F(X,t) pour la rotation'],[290,465;350,465])
add_line([sys,'/','F(X,t) pour la rotation'],[485,465;795,465])
add_line([sys,'/','F(X,t) pour la rotation'],[845,370;870,370])
add_line([sys,'/','F(X,t) pour la rotation'],[905,370;940,370])
add_line([sys,'/','F(X,t) pour la rotation'],[75,370;255,370])
add_line([sys,'/','F(X,t) pour la rotation'],[755,370;795,370])
add_line([sys,'/','F(X,t) pour la rotation'],[785,275;795,275])
add_line([sys,'/','F(X,t) pour la rotation'],[665,275;675,275])
add_line([sys,'/','F(X,t) pour la rotation'],[395,370;435,370])
add_line([sys,'/','F(X,t) pour la rotation'],[545,370;720,370])
add_line([sys,'/','F(X,t) pour la rotation'],[380,280;540,280])
add_line([sys,'/','F(X,t) pour la rotation'],[380,170;540,170])
add_line([sys,'/','F(X,t) pour la rotation'],[110,370;110,495;230,495])
add_line([sys,'/','F(X,t) pour la rotation'],[110,370;110,280;150,280])
add_line([sys,'/','F(X,t) pour la rotation'],[110,280;110,170;150,170])
add_line([sys,'/','F(X,t) pour la rotation'],[575,225;585,225;585,275;615,275])
set_param([sys,'/','F(X,t) pour la rotation'],...
		'Mask Display','F(X , t ) \n\nPOUR LA ROTATION')


%     Finished composite block 'F(X,t) pour la rotation'.

set_param([sys,'/','F(X,t) pour la rotation'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[185,233,410,317])

add_block('built-in/Note',[sys,'/','Drive quaternion (4)'])
set_param([sys,'/','Drive quaternion (4)'],...
		'position',[470,420,475,425])


%     Subsystem  'UnNamed2'.

new_system([sys,'/','UnNamed2'])
set_param([sys,'/','UnNamed2'],'Location',[588,239,931,333])

add_block('built-in/Note',[sys,'/',['UnNamed2/Drive du quaternion d''attitude']])
set_param([sys,'/',['UnNamed2/Drive du quaternion d''attitude']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[185,5,190,10])

add_block('built-in/Outport',[sys,'/','UnNamed2/Outport'])
set_param([sys,'/','UnNamed2/Outport'],...
		'position',[260,45,280,65])

add_block('built-in/Inport',[sys,'/','UnNamed2/Inport'])
set_param([sys,'/','UnNamed2/Inport'],...
		'position',[80,45,100,65])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed2/deriv_qt.m'])
set_param([sys,'/','UnNamed2/deriv_qt.m'],...
		'MATLAB Fcn','deriv_qt(u)',...
		'Output Width','4',...
		'position',[150,39,220,71])
add_line([sys,'/','UnNamed2'],[225,55;255,55])
add_line([sys,'/','UnNamed2'],[105,55;145,55])
set_param([sys,'/','UnNamed2'],...
		'Mask Display','F(X , t)\n\nPOUR LE QUATERNION')


%     Finished composite block 'UnNamed2'.

set_param([sys,'/','UnNamed2'],...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[180,368,395,472])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'hide name',0,...
		'inputs','[3 4]',...
		'position',[555,204,615,491])

add_block('built-in/Note',[sys,'/','3'])
set_param([sys,'/','3'],...
		'position',[575,255,580,260])

add_block('built-in/Note',[sys,'/','4'])
set_param([sys,'/','4'],...
		'position',[570,395,575,400])

add_block('built-in/Clock',[sys,'/','Clock'])
set_param([sys,'/','Clock'],...
		'BackGround',7,...
		'position',[110,138,145,172])


%     Subsystem  'Extras7'.

new_system([sys,'/','Extras7'])
set_param([sys,'/','Extras7'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras7'],...
		'Mask Display','Voir les courbes\nvitesses angulaires\np, q, r (rd/s)',...
		'Mask Dialogue','eval(''plot(temps,p,''''y'''',temps,q,''''c'''',temps,r,''''m'''');grid;figure(gcf)'')')


%     Finished composite block 'Extras7'.

set_param([sys,'/','Extras7'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[120,705,325,766])


%     Subsystem  'Extras16'.

new_system([sys,'/','Extras16'])
set_param([sys,'/','Extras16'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras16'],...
		'Mask Display','Voir la courbe du\nmoment magntique\nMx',...
		'Mask Dialogue','eval(''plot(temps,Mx);grid;figure(gcf)'')')


%     Finished composite block 'Extras16'.

set_param([sys,'/','Extras16'],...
		'ForeGround',1,...
		'BackGround',4,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[345,630,615,691])


%     Subsystem  'Extras9'.

new_system([sys,'/','Extras9'])
set_param([sys,'/','Extras9'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras9'],...
		'Mask Display','Voir la courbe du\nmoment magntique\nMy',...
		'Mask Dialogue','eval(''plot(temps,My);grid;figure(gcf)'')')


%     Finished composite block 'Extras9'.

set_param([sys,'/','Extras9'],...
		'ForeGround',1,...
		'BackGround',4,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[345,700,615,761])


%     Subsystem  'Extras15'.

new_system([sys,'/','Extras15'])
set_param([sys,'/','Extras15'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras15'],...
		'Mask Display','Voir la courbe du\nmoment magntique\nMz',...
		'Mask Dialogue','eval(''plot(temps,Mz);grid;figure(gcf)'')')


%     Finished composite block 'Extras15'.

set_param([sys,'/','Extras15'],...
		'ForeGround',1,...
		'BackGround',4,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[345,765,615,826])


%     Subsystem  'Extras6'.

new_system([sys,'/','Extras6'])
set_param([sys,'/','Extras6'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras6'],...
		'Mask Display','Voir la courbe\n\nenergie absolue (J)',...
		'Mask Dialogue','eval(''plot(temps,energie);grid;figure(gcf)'')')


%     Finished composite block 'Extras6'.

set_param([sys,'/','Extras6'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[640,625,810,691])


%     Subsystem  'Extras13'.

new_system([sys,'/','Extras13'])
set_param([sys,'/','Extras13'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras13'],...
		'Mask Display','Voir la courbe\nangle beta(B,y)\nen degrs',...
		'Mask Dialogue','eval(''plot(temps,beta_steyn);grid;figure(gcf)'')')


%     Finished composite block 'Extras13'.

set_param([sys,'/','Extras13'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[120,775,325,826])


%     Subsystem  'Extras14'.

new_system([sys,'/','Extras14'])
set_param([sys,'/','Extras14'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras14'],...
		'Mask Display','Voir la courbe\nangle entre Y et y\nen degrs',...
		'Mask Dialogue','eval(''plot(temps,angle_Y_y);grid;figure(gcf)'')')


%     Finished composite block 'Extras14'.

set_param([sys,'/','Extras14'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[715,855,890,921])


%     Subsystem  'Extras19'.

new_system([sys,'/','Extras19'])
set_param([sys,'/','Extras19'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras19'],...
		'Mask Display','Vrification\n\nq constante',...
		'Mask Dialogue','eval(''plot(temps,q);grid;figure(gcf)'')')


%     Finished composite block 'Extras19'.

set_param([sys,'/','Extras19'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[520,855,695,921])


%     Subsystem  'Extras18'.

new_system([sys,'/','Extras18'])
set_param([sys,'/','Extras18'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras18'],...
		'Mask Display','Vrification\n\nenergie constante',...
		'Mask Dialogue','eval(''plot(temps,energie);grid;figure(gcf)'')')


%     Finished composite block 'Extras18'.

set_param([sys,'/','Extras18'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[320,855,495,921])


%     Subsystem  'Extras17'.

new_system([sys,'/','Extras17'])
set_param([sys,'/','Extras17'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras17'],...
		'Mask Display','Vrification\np2plusr2 constante\nrotation transverse',...
		'Mask Dialogue','eval(''plot(temps,p2plusr2);grid;figure(gcf)'')')


%     Finished composite block 'Extras17'.

set_param([sys,'/','Extras17'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[120,855,295,926])


%     Subsystem  'Extras10'.

new_system([sys,'/','Extras10'])
set_param([sys,'/','Extras10'],'Location',[4,44,1012,680])
set_param([sys,'/','Extras10'],...
		'Mask Display','Couleurs des courbes\nroulis=jaune\ntangage=cyan\nlacet=magenta')


%     Finished composite block 'Extras10'.

set_param([sys,'/','Extras10'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[850,700,1080,786])

add_block('built-in/Note',[sys,'/',['RESOLUTION PAR LES QUATERNIONS AVEC NORMALISATION',13,'']])
set_param([sys,'/',['RESOLUTION PAR LES QUATERNIONS AVEC NORMALISATION',13,'']],...
		'ForeGround',5,...
		'Font Name','Arial',...
		'Font Size',18,...
		'position',[660,90,665,95])

add_block('built-in/Note',[sys,'/','Ci-dessous cliquer pour obtenir les tracs de courbes'])
set_param([sys,'/','Ci-dessous cliquer pour obtenir les tracs de courbes'],...
		'Font Name','Arial',...
		'Font Angle','italic',...
		'Font Size',16,...
		'position',[480,570,485,575])

add_block('built-in/Note',[sys,'/',['L''initialisation',13,' lance prec_dat.m']])
set_param([sys,'/',['L''initialisation',13,' lance prec_dat.m']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'Mask Display','',...
		'position',[965,630,970,635])


%     Subsystem  'Extras1'.

new_system([sys,'/','Extras1'])
set_param([sys,'/','Extras1'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras1'],...
		'Mask Display','INITIALISATION\npar double clic souris\nCAS GENERAL',...
		'Mask Dialogue','eval(''clc;clear;prec_dat'')')


%     Finished composite block 'Extras1'.

set_param([sys,'/','Extras1'],...
		'ForeGround',4,...
		'BackGround',6,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[860,565,1075,636])


%     Subsystem  'Angle (Y,y)'.

new_system([sys,'/','Angle (Y,y)'])
set_param([sys,'/','Angle (Y,y)'],'Location',[-32000,-32000,-31840,-31975])

add_block('built-in/Inport',[sys,'/','Angle (Y,y)/in_1'])
set_param([sys,'/','Angle (Y,y)/in_1'],...
		'position',[15,80,35,100])

add_block('built-in/To Workspace',[sys,'/','Angle (Y,y)/To Workspace5'])
set_param([sys,'/','Angle (Y,y)/To Workspace5'],...
		'hide name',0,...
		'mat-name','angle_Y_y',...
		'buffer','points_trace',...
		'position',[245,80,325,100])

add_block('built-in/MATLAB Fcn',[sys,'/','Angle (Y,y)/Calcul de  angle(Y,y)'])
set_param([sys,'/','Angle (Y,y)/Calcul de  angle(Y,y)'],...
		'MATLAB Fcn','180/pi*acos(2*(u(4)^2+u(6)^2)-1)',...
		'Output Width','1',...
		'position',[75,73,190,107])

add_block('built-in/Note',[sys,'/','Angle (Y,y)/Angle en degrs'])
set_param([sys,'/','Angle (Y,y)/Angle en degrs'],...
		'position',[280,55,285,60])

add_block('built-in/Outport',[sys,'/','Angle (Y,y)/out_1'])
set_param([sys,'/','Angle (Y,y)/out_1'],...
		'position',[340,105,360,125])
add_line([sys,'/','Angle (Y,y)'],[40,90;70,90])
add_line([sys,'/','Angle (Y,y)'],[195,90;240,90])
add_line([sys,'/','Angle (Y,y)'],[210,90;210,115;335,115])
set_param([sys,'/','Angle (Y,y)'],...
		'Mask Display','SORTIE A\nANGLE ( Y,y) en degrs')


%     Finished composite block 'Angle (Y,y)'.

set_param([sys,'/','Angle (Y,y)'],...
		'position',[950,373,1105,417])

add_block('built-in/Scope',[sys,'/','Scope1'])
set_param([sys,'/','Scope1'],...
		'Vgain','180.000000',...
		'Hgain','20000.000000',...
		'Vmax','360.000000',...
		'Hmax','40000.000000',...
		'Window',[288,0,933,496],...
		'position',[1145,380,1175,410])

add_block('built-in/Integrator',[sys,'/','Integrator1'])
set_param([sys,'/','Integrator1'],...
		'hide name',0,...
		'Initial','[vp0 vq0 vr0 qt00 qt10 qt20 qt30]',...
		'position',[675,324,720,376])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn3'])
set_param([sys,'/','MATLAB Fcn3'],...
		'hide name',0,...
		'MATLAB Fcn','normalis(u)',...
		'Output Width','7',...
		'Mask Display','Normalisation',...
		'position',[735,326,825,374])


%     Subsystem  'Subsystem2'.

new_system([sys,'/','Subsystem2'])
set_param([sys,'/','Subsystem2'],'Location',[559,482,1161,775])

add_block('built-in/Inport',[sys,'/','Subsystem2/in_1'])
set_param([sys,'/','Subsystem2/in_1'],...
		'position',[15,70,35,90])

add_block('built-in/MATLAB Fcn',[sys,'/',['Subsystem2/fonction ',13,'d''arrt']])
set_param([sys,'/',['Subsystem2/fonction ',13,'d''arrt']],...
		'MATLAB Fcn','stopderv(u)',...
		'Output Width','1',...
		'position',[55,63,115,97])

add_block('built-in/Stop Simulation',[sys,'/','Subsystem2/Stop Simulation'])
set_param([sys,'/','Subsystem2/Stop Simulation'],...
		'position',[350,63,390,97])

add_block('built-in/To Workspace',[sys,'/','Subsystem2/To Workspace'])
set_param([sys,'/','Subsystem2/To Workspace'],...
		'mat-name','stop',...
		'position',[370,27,420,43])

add_block('built-in/Gain',[sys,'/','Subsystem2/Gain'])
set_param([sys,'/','Subsystem2/Gain'],...
		'BackGround',7,...
		'Gain','0',...
		'position',[185,63,265,97])

add_block('built-in/Note',[sys,'/','Subsystem2/Pour mettre le stop hors course, fixer le gain  0'])
set_param([sys,'/','Subsystem2/Pour mettre le stop hors course, fixer le gain  0'],...
		'ForeGround',7,...
		'Font Name','Arial',...
		'Font Size',18,...
		'position',[345,140,350,145])
add_line([sys,'/','Subsystem2'],[40,80;50,80])
add_line([sys,'/','Subsystem2'],[120,80;180,80])
add_line([sys,'/','Subsystem2'],[270,80;345,80])
add_line([sys,'/','Subsystem2'],[300,80;300,35;365,35])
set_param([sys,'/','Subsystem2'],...
		'Mask Display','STOP')


%     Finished composite block 'Subsystem2'.

set_param([sys,'/','Subsystem2'],...
		'orientation',2,...
		'ForeGround',5,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',16,...
		'position',[685,193,770,247])

add_block('built-in/Note',[sys,'/','p q r Q'])
set_param([sys,'/','p q r Q'],...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[895,190,900,195])


%     Subsystem  'Sorties'.

new_system([sys,'/','Sorties'])
set_param([sys,'/','Sorties'],'Location',[-32000,-32000,-31840,-31975])

add_block('built-in/Demux',[sys,'/','Sorties/Demux'])
set_param([sys,'/','Sorties/Demux'],...
		'outputs','[3 4]',...
		'position',[470,339,520,506])

add_block('built-in/MATLAB Fcn',[sys,'/','Sorties/MATLAB Fcn1'])
set_param([sys,'/','Sorties/MATLAB Fcn1'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','angles(u)',...
		'Output Width','3',...
		'position',[700,448,760,482])

add_block('built-in/To Workspace',[sys,'/','Sorties/To Workspace14'])
set_param([sys,'/','Sorties/To Workspace14'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','lacet',...
		'buffer','points_trace',...
		'position',[965,490,1035,510])

add_block('built-in/To Workspace',[sys,'/','Sorties/To Workspace12'])
set_param([sys,'/','Sorties/To Workspace12'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','roulis',...
		'buffer','points_trace',...
		'position',[965,420,1035,440])

add_block('built-in/Demux',[sys,'/','Sorties/Demux2'])
set_param([sys,'/','Sorties/Demux2'],...
		'outputs','3',...
		'position',[860,413,905,517])

add_block('built-in/Note',[sys,'/','Sorties/Energie'])
set_param([sys,'/','Sorties/Energie'],...
		'position',[885,390,890,395])

add_block('built-in/Note',[sys,'/','Sorties/Drive de Q'])
set_param([sys,'/','Sorties/Drive de Q'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[635,665,640,670])

add_block('built-in/MATLAB Fcn',[sys,'/','Sorties/MATLAB Fcn4'])
set_param([sys,'/','Sorties/MATLAB Fcn4'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','omegaorb(u)',...
		'Output Width','3',...
		'position',[815,621,895,659])

add_block('built-in/Note',[sys,'/','Sorties/Quaternion Q'])
set_param([sys,'/','Sorties/Quaternion Q'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[600,435,605,440])

add_block('built-in/To Workspace',[sys,'/','Sorties/To Workspace5'])
set_param([sys,'/','Sorties/To Workspace5'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','accel_angulaire',...
		'buffer','points_trace',...
		'position',[565,562,670,598])

add_block('built-in/Mux',[sys,'/','Sorties/Mux'])
set_param([sys,'/','Sorties/Mux'],...
		'inputs','[4 4]',...
		'position',[735,591,770,689])

add_block('built-in/Note',[sys,'/',['Sorties/Q''']])
set_param([sys,'/',['Sorties/Q''']],...
		'position',[710,670,715,675])

add_block('built-in/Note',[sys,'/','Sorties/Q'])
set_param([sys,'/','Sorties/Q'],...
		'position',[705,590,710,595])

add_block('built-in/To Workspace',[sys,'/','Sorties/To Workspace7'])
set_param([sys,'/','Sorties/To Workspace7'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','energie',...
		'buffer','points_trace',...
		'position',[850,370,920,390])

add_block('built-in/MATLAB Fcn',[sys,'/','Sorties/MATLAB Fcn3'])
set_param([sys,'/','Sorties/MATLAB Fcn3'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','ENERGIE(u)',...
		'Output Width','1',...
		'position',[745,361,825,399])

add_block('built-in/Fcn',[sys,'/','Sorties/Fcn'])
set_param([sys,'/','Sorties/Fcn'],...
		'Expr','(u(1)^2+u(3)^2)^0.5',...
		'position',[720,325,760,345])

add_block('built-in/To Workspace',[sys,'/','Sorties/To Workspace9'])
set_param([sys,'/','Sorties/To Workspace9'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','p2plusr2',...
		'buffer','points_trace',...
		'position',[805,325,875,345])

add_block('built-in/Demux',[sys,'/','Sorties/Demux1'])
set_param([sys,'/','Sorties/Demux1'],...
		'outputs','[3 4]',...
		'position',[470,539,520,706])

add_block('built-in/Inport',[sys,'/','Sorties/in_1'])
set_param([sys,'/','Sorties/in_1'],...
		'position',[400,415,420,435])

add_block('built-in/Note',[sys,'/',['Sorties/Entre de',13,'p q r Q']])
set_param([sys,'/',['Sorties/Entre de',13,'p q r Q']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[420,365,425,370])

add_block('built-in/To Workspace',[sys,'/','Sorties/To Workspace13'])
set_param([sys,'/','Sorties/To Workspace13'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','tangage',...
		'buffer','points_trace',...
		'position',[965,455,1035,475])

add_block('built-in/To Workspace',[sys,'/','Sorties/To Workspace10'])
set_param([sys,'/','Sorties/To Workspace10'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','omega_tmc',...
		'buffer','points_trace',...
		'position',[800,272,900,298])

add_block('built-in/Demux',[sys,'/','Sorties/Demux3'])
set_param([sys,'/','Sorties/Demux3'],...
		'outputs','3',...
		'position',[610,158,655,262])

add_block('built-in/Inport',[sys,'/','Sorties/in_2'])
set_param([sys,'/','Sorties/in_2'],...
		'Port','2',...
		'position',[390,615,410,635])

add_block('built-in/Gain',[sys,'/',['Sorties/Conversion',13,'rd // degrs']])
set_param([sys,'/',['Sorties/Conversion',13,'rd // degrs']],...
		'Gain','180/pi',...
		'position',[780,452,805,478])

add_block('built-in/Note',[sys,'/','Sorties/Vrification  rotation transversale'])
set_param([sys,'/','Sorties/Vrification  rotation transversale'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[805,295,810,300])

add_block('built-in/To Workspace',[sys,'/','Sorties/To Workspace15'])
set_param([sys,'/','Sorties/To Workspace15'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','p',...
		'buffer','points_trace',...
		'position',[790,165,860,185])

add_block('built-in/To Workspace',[sys,'/','Sorties/To Workspace17'])
set_param([sys,'/','Sorties/To Workspace17'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','r',...
		'buffer','points_trace',...
		'position',[795,235,865,255])

add_block('built-in/Gain',[sys,'/',['Sorties/Conversion',13,'rd // degrs1']])
set_param([sys,'/',['Sorties/Conversion',13,'rd // degrs1']],...
		'hide name',0,...
		'Gain','180/pi',...
		'position',[720,162,745,188])

add_block('built-in/Gain',[sys,'/',['Sorties/Conversion',13,'rd // degrs2']])
set_param([sys,'/',['Sorties/Conversion',13,'rd // degrs2']],...
		'hide name',0,...
		'Gain','180/pi',...
		'position',[720,197,745,223])

add_block('built-in/Gain',[sys,'/',['Sorties/Conversion',13,'rd // degrs3']])
set_param([sys,'/',['Sorties/Conversion',13,'rd // degrs3']],...
		'hide name',0,...
		'Gain','180/pi',...
		'position',[720,232,745,258])

add_block('built-in/Note',[sys,'/',['Sorties/SORTIES ET TRAITEMENT DE LA SORTIE',13,'POUR VERIFICATIONS DE FONCTIONNALITE']])
set_param([sys,'/',['Sorties/SORTIES ET TRAITEMENT DE LA SORTIE',13,'POUR VERIFICATIONS DE FONCTIONNALITE']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',20,...
		'position',[635,15,640,20])

add_block('built-in/Note',[sys,'/',['Sorties/Vitesses angulaires absolues',13,'autour des axes x y z',13,'en degrs//s']])
set_param([sys,'/',['Sorties/Vitesses angulaires absolues',13,'autour des axes x y z',13,'en degrs//s']],...
		'position',[960,165,965,170])

add_block('built-in/Note',[sys,'/','Sorties/Angles en degrs'])
set_param([sys,'/','Sorties/Angles en degrs'],...
		'position',[1095,465,1100,470])

add_block('built-in/To Workspace',[sys,'/','Sorties/To Workspace16'])
set_param([sys,'/','Sorties/To Workspace16'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','q',...
		'buffer','points_trace',...
		'position',[795,200,865,220])

add_block('built-in/To Workspace',[sys,'/','Sorties/To Workspace11'])
set_param([sys,'/','Sorties/To Workspace11'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','omega_quat',...
		'buffer','points_trace',...
		'position',[1020,624,1105,656])

add_block('built-in/Gain',[sys,'/',['Sorties/Conversion',13,'rd // degrs4']])
set_param([sys,'/',['Sorties/Conversion',13,'rd // degrs4']],...
		'Gain','180/pi',...
		'position',[945,627,970,653])

add_block('built-in/Note',[sys,'/',['Sorties/Rotation atellite par',13,'rapport aux axes orbitaux',13,'exprime en axes satellite']])
set_param([sys,'/',['Sorties/Rotation atellite par',13,'rapport aux axes orbitaux',13,'exprime en axes satellite']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[965,685,970,690])

add_block('built-in/Note',[sys,'/',['Sorties/NB : le calcul de la rotation, soit par intgration --> p q r',13,'']])
set_param([sys,'/',['Sorties/NB : le calcul de la rotation, soit par intgration --> p q r',13,'']],...
		'Font Size',16,...
		'position',[565,780,570,785])

add_block('built-in/Note',[sys,'/','Sorties/soit par le produit quaternionique'])
set_param([sys,'/','Sorties/soit par le produit quaternionique'],...
		'Font Size',16,...
		'position',[720,805,725,810])

add_block('built-in/Note',[sys,'/','Sorties/permet de vrifier, en partie, les calculs'])
set_param([sys,'/','Sorties/permet de vrifier, en partie, les calculs'],...
		'Font Size',16,...
		'position',[535,830,540,835])

add_block('built-in/Clock',[sys,'/','Sorties/Clock'])
set_param([sys,'/','Sorties/Clock'],...
		'position',[265,220,285,240])

add_block('built-in/To Workspace',[sys,'/','Sorties/To Workspace8'])
set_param([sys,'/','Sorties/To Workspace8'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','temps',...
		'buffer','points_trace',...
		'position',[325,220,395,240])
add_line([sys,'/','Sorties'],[525,380;740,380])
add_line([sys,'/','Sorties'],[830,380;845,380])
add_line([sys,'/','Sorties'],[425,425;465,425])
add_line([sys,'/','Sorties'],[525,465;695,465])
add_line([sys,'/','Sorties'],[290,230;320,230])
add_line([sys,'/','Sorties'],[660,380;660,335;715,335])
add_line([sys,'/','Sorties'],[765,335;800,335])
add_line([sys,'/','Sorties'],[660,335;660,285;795,285])
add_line([sys,'/','Sorties'],[415,625;465,625])
add_line([sys,'/','Sorties'],[525,580;560,580])
add_line([sys,'/','Sorties'],[525,665;730,665])
add_line([sys,'/','Sorties'],[675,465;675,615;730,615])
add_line([sys,'/','Sorties'],[775,640;810,640])
add_line([sys,'/','Sorties'],[765,465;775,465])
add_line([sys,'/','Sorties'],[810,465;855,465])
add_line([sys,'/','Sorties'],[910,430;960,430])
add_line([sys,'/','Sorties'],[910,465;960,465])
add_line([sys,'/','Sorties'],[910,500;960,500])
add_line([sys,'/','Sorties'],[550,380;550,210;605,210])
add_line([sys,'/','Sorties'],[660,175;715,175])
add_line([sys,'/','Sorties'],[750,175;785,175])
add_line([sys,'/','Sorties'],[660,210;715,210])
add_line([sys,'/','Sorties'],[750,210;790,210])
add_line([sys,'/','Sorties'],[750,245;790,245])
add_line([sys,'/','Sorties'],[660,245;715,245])
add_line([sys,'/','Sorties'],[900,640;940,640])
add_line([sys,'/','Sorties'],[975,640;1015,640])
set_param([sys,'/','Sorties'],...
		'Mask Display','SORTIE DES ANGLES\n\nEN DEGRES & ENERGIE')


%     Finished composite block 'Sorties'.

set_param([sys,'/','Sorties'],...
		'position',[940,201,1135,274])

add_block('built-in/Note',[sys,'/',['p'' q'' r'' Q''']])
set_param([sys,'/',['p'' q'' r'' Q''']],...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[760,255,765,260])
add_line(sys,[830,350;905,350;905,510;95,505;95,420;175,420])
add_line(sys,[620,350;670,350])
add_line(sys,[415,275;550,275])
add_line(sys,[400,420;550,420])
add_line(sys,[655,350;655,255;935,255])
add_line(sys,[95,420;95,275;180,275])
add_line(sys,[1110,395;1140,395])
add_line(sys,[905,395;945,395])
add_line(sys,[725,350;730,350])
add_line(sys,[850,350;850,220;935,220])
add_line(sys,[850,220;850,220;775,220])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
